@@ -5,7 +5,6 @@ package Business::KontoCheck;
 use 5.006000;
 use strict;
 use warnings;
-use encoding 'ISO8859-1';
 
 require Exporter;
 
@@ -46,7 +45,7 @@ our @EXPORT_OK = qw(kto_check kto_check_str kto_check_blz
 
 our @EXPORT = qw( lut_init kto_check kto_check_blz kto_check_at %kto_retval );
 
-our $VERSION = '5.8';
+our $VERSION = '5.9';
 
 require XSLoader;
 XSLoader::load('Business::KontoCheck', $VERSION);
@@ -1312,6 +1311,8 @@ sub iban_iban_regel1
 
 
 %Business::KontoCheck::kto_retval = (
+-152 => 'Ungltiger Zhler in regulrem Ausdruck (innerhalb von {})',
+-151 => 'Ungltiger regulrer Ausdruck (enthlt zwei Zeichen aus [+?*] nacheinander)',
 -150 => 'Ungltiges Handle angegeben',
 -149 => 'Ungltiger Index fr die biq_*() Funktionen',
 -148 => 'Der Array-Index liegt auerhalb des gltigen Bereichs',
@@ -1464,6 +1465,8 @@ sub iban_iban_regel1
   25 => 'ok, es wurde ein (weggelassenes) Unterkonto angefgt',
   26 => 'ok, fr den BIC wurde die Zweigstellennummer allerdings durch XXX ersetzt',
 
+'INVALID_REGULAR_EXPRESSION_CNT'         => 'Ungltiger Zhler in regulrem Ausdruck (innerhalb von {})',
+'INVALID_REGULAR_EXPRESSION'             => 'Ungltiger regulrer Ausdruck (enthlt zwei Zeichen aus [+?*] nacheinander)',
 'INVALID_HANDLE'                         => 'Ungltiges Handle angegeben',
 'INVALID_BIQ_INDEX'                      => 'Ungltiger Index fr die biq_*() Funktionen',
 'ARRAY_INDEX_OUT_OF_RANGE'               => 'Der Array-Index liegt auerhalb des gltigen Bereichs',
@@ -1618,6 +1621,8 @@ sub iban_iban_regel1
 );
 
 %Business::KontoCheck::kto_retval_kurz = (
+-152 => 'INVALID_REGULAR_EXPRESSION_CNT',
+-151 => 'INVALID_REGULAR_EXPRESSION',
 -150 => 'INVALID_HANDLE',
 -149 => 'INVALID_BIQ_INDEX',
 -148 => 'ARRAY_INDEX_OUT_OF_RANGE',
